bayespy.nodes.GaussianGammaISO
==============================

.. currentmodule:: bayespy.nodes

.. autoclass:: GaussianGammaISO

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaISO.__init__
      ~GaussianGammaISO.add_plate_axis
      ~GaussianGammaISO.broadcasting_multiplier
      ~GaussianGammaISO.delete
      ~GaussianGammaISO.get_gaussian_mean_and_variance
      ~GaussianGammaISO.get_gradient
      ~GaussianGammaISO.get_marginal_logpdf
      ~GaussianGammaISO.get_mask
      ~GaussianGammaISO.get_moments
      ~GaussianGammaISO.get_parameters
      ~GaussianGammaISO.get_riemannian_gradient
      ~GaussianGammaISO.get_shape
      ~GaussianGammaISO.has_plotter
      ~GaussianGammaISO.initialize_from_parameters
      ~GaussianGammaISO.initialize_from_prior
      ~GaussianGammaISO.initialize_from_random
      ~GaussianGammaISO.initialize_from_value
      ~GaussianGammaISO.load
      ~GaussianGammaISO.logpdf
      ~GaussianGammaISO.lower_bound_contribution
      ~GaussianGammaISO.lowerbound
      ~GaussianGammaISO.move_plates
      ~GaussianGammaISO.observe
      ~GaussianGammaISO.pdf
      ~GaussianGammaISO.plot
      ~GaussianGammaISO.plotmatrix
      ~GaussianGammaISO.random
      ~GaussianGammaISO.save
      ~GaussianGammaISO.set_parameters
      ~GaussianGammaISO.set_plotter
      ~GaussianGammaISO.show
      ~GaussianGammaISO.unobserve
      ~GaussianGammaISO.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaISO.dims
      ~GaussianGammaISO.plates
      ~GaussianGammaISO.plates_multiplier
   
   